{! TODO: gonna need to collapse multiple newlines to single newlines !}
{#entry.loaded_parts}
{^data_idx}
{content}
{:else}
## {title}

{#attrs}
   * {key}: {value}{/attrs}

{content}
{/data_idx}
{/entry.loaded_parts}
